Props

Struct Props 

pub struct Props {
Show 31 fields pub aria_label: AttrValue, pub children: Children, pub classes: Classes, pub color: Color, pub disabled: bool, pub disable_elevation: bool, pub full_width: bool, pub loading: bool, pub loading_indicator: Option<Html>, pub loading_position: Position, pub start_icon: Option<Html>, pub end_icon: Option<Html>, pub size: Size, pub style: AttrValue, pub tab_index: Option<i32>, pub variant: ButtonVariant, pub on_blur: Option<Callback<FocusEvent>>, pub on_click: Option<Callback<MouseEvent>>, pub on_context_menu: Option<Callback<MouseEvent>>, pub on_drag_leave: Option<Callback<DragEvent>>, pub on_focus: Option<Callback<FocusEvent>>, pub on_focus_visible: Option<Callback<FocusEvent>>, pub on_key_down: Option<Callback<KeyboardEvent>>, pub on_key_up: Option<Callback<KeyboardEvent>>, pub on_mouse_down: Option<Callback<MouseEvent>>, pub on_mouse_enter: Option<Callback<MouseEvent>>, pub on_mouse_leave: Option<Callback<MouseEvent>>, pub on_mouse_up: Option<Callback<MouseEvent>>, pub on_touch_end: Option<Callback<TouchEvent>>, pub on_touch_move: Option<Callback<TouchEvent>>, pub on_touch_start: Option<Callback<TouchEvent>>,
}

Fields

aria_label: AttrValuechildren: Childrenclasses: Classescolor: Color

Default value is Color::Default.

disabled: booldisable_elevation: boolfull_width: boolloading: bool

If true, the loading indicator is shown.

Default is false.

loading_indicator: Option<Html>

Element placed before the children if the button is in loading state.

loading_position: Positionstart_icon: Option<Html>end_icon: Option<Html>size: Size

Default is Size::Medium.

style: AttrValuetab_index: Option<i32>variant: ButtonVarianton_blur: Option<Callback<FocusEvent>>on_click: Option<Callback<MouseEvent>>on_context_menu: Option<Callback<MouseEvent>>on_drag_leave: Option<Callback<DragEvent>>on_focus: Option<Callback<FocusEvent>>on_focus_visible: Option<Callback<FocusEvent>>

Callback fired when the component is focused with a keyboard.

on_key_down: Option<Callback<KeyboardEvent>>on_key_up: Option<Callback<KeyboardEvent>>on_mouse_down: Option<Callback<MouseEvent>>on_mouse_enter: Option<Callback<MouseEvent>>on_mouse_leave: Option<Callback<MouseEvent>>on_mouse_up: Option<Callback<MouseEvent>>on_touch_end: Option<Callback<TouchEvent>>on_touch_move: Option<Callback<TouchEvent>>on_touch_start: Option<Callback<TouchEvent>>